==> laok-0.2.15.tar.gz: laok-0.2.15/laok/ml/cluster/_sklearn.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022/5/11 21:54:21

@author: LiuKuan
@copyright: Apache License, Version 2.0
'''
#===============================================================================
'''  包装了 sklearn所支持的聚类算法
'''
#===============================================================================

cluster_list = [
    'AffinityPropagation',
    'Agglomerative',
    'Birch',
    'DBScan',
    'DBScan_daal'
    'GaussianMixture',
    'BayesianGaussianMixture',
    'KMeans',
    'KMeans_daal',
    'KMeansBisecting',
    'KMeansMiniBatch',
    'MeanShift',
    'OPTICS',
    'Spectral',
    'SpectralBiing',
    'SpectralCoing'
]

def get_cluster(name = "KMeans"):
    name = name.lower()
    if name == 'AffinityPropagation'.lower():
        from sklearn.cluster import AffinityPropagation as Alg
        # 聚合聚类涉及合并示例，直到达到所需的群集数量为止。它是层次聚类方法的更广泛类的一部分
        # labels_  cluster_centers_indices_  cluster_centers_  affinity_matrix_ n_iter_
    elif name == 'Agglomerative'.lower():
        from sklearn.cluster import AgglomerativeClustering as Alg
        # 聚合聚类涉及合并示例，直到达到所需的群集数量为止。它是层次聚类方法的更广泛类的一部分
        # labels_  n_clusters_ n_leaves_ n_connected_components_  children_ distances_
    elif name == 'Birch'.lower():
        from sklearn.cluster import Birch as Alg
        # BIRCH 聚类（ BIRCH 是平衡迭代减少的缩写，聚类使用层次结构)包括构造一个树状结构，从中提取聚类质心。
        # labels_  subcluster_centers_  subcluster_labels_
    elif name == 'DBScan'.lower():
        from sklearn.cluster import DBSCAN as Alg
        # 聚类（其中 DBSCAN 是基于密度的空间聚类的噪声应用程序）涉及在域中寻找高密度区域，并将其周围的特征空间区域扩展为群集
        # labels_   components_     core_sample_indices_
    elif name == 'DBScan_daal'.lower(): 
        from daal4py.sklearn.cluster import DBSCAN as Alg
        # intel加速版本的 DBScan
        # labels_   components_     core_sample_indices_
    elif name == 'GaussianMixture'.lower(): 
        from sklearn.mixture import GaussianMixture as Alg
        # 高斯混合模型总结了一个多变量概率密度函数，顾名思义就是混合了高斯概率分布。
        # labels_   weights_  means_  covariances_  precisions_  precisions_cholesky_  converged_  n_iter_  lower_bound_
    elif name == 'BayesianGaussianMixture'.lower(): 
        from sklearn.mixture import BayesianGaussianMixture as Alg
        # labels_  weights_  means_  covariances_  precisions_  precisions_cholesky_  converged_  n_iter_
        # lower_bound_  weight_concentration_prior_  weight_concentration_  mean_precision_prior_  
        # mean_precision_ mean_prior_  degrees_of_freedom_prior_  degrees_of_freedom_  covariance_prior_
    elif name == 'KMeans'.lower(): 
        from sklearn.cluster import KMeans as Alg
        # labels_  cluster_centers_  inertia_  n_iter_
    elif name == 'KMeans_daal'.lower(): 
        from daal4py.sklearn.cluster import KMeans as Alg
        # labels_  cluster_centers_  inertia_  n_iter_
    elif name == 'KMeansBisecting'.lower(): 
        from sklearn.cluster import BisectingKMeans as Alg
        # labels_  cluster_centers_  inertia_  n_features_in_
    elif name == 'KMeansMiniBatch'.lower(): 
        from sklearn.cluster import MiniBatchKMeans as Alg
        # K-均值是 K-均值的修改版本，它使用小批量的样本而不是整个数据集对群集质心进行更新，
        # 这可以使大数据集的更新速度更快，并且可能对统计噪声更健壮，我们建议使用 k-均值聚类的迷你批量优化。
        # 与经典批处理算法相比，这降低了计算成本的数量级，同时提供了比在线随机梯度下降更好的解决方案。
        # labels_  n_iter_  inertia_
    elif name == 'MeanShift'.lower(): 
        from sklearn.cluster import MeanShift as Alg
        # 均值漂移聚类涉及到根据特征空间中的实例密度来寻找和调整质心。
        # labels_  cluster_centers_  n_iter_
    elif name == 'OPTICS'.lower(): 
        from sklearn.cluster import OPTICS as Alg
        # 聚类（ OPTICS 短于订购点数以标识聚类结构）是上述 DBSCAN 的修改版本
        # labels_  reachability_  ordering_  core_distances_  predecessor_ cluster_hierarchy_
    elif name == 'Spectral'.lower(): 
        from sklearn.cluster import SpectralClustering as Alg
        # labels_  affinity_matrix_
    elif name == 'SpectralBiing'.lower(): 
        from sklearn.cluster import SpectralBiclustering as Alg
        # row_labels_  column_labels_  columns_  rows_
    elif name == 'SpectralCoing'.lower(): 
        from sklearn.cluster import SpectralCoclustering as Alg
        # row_labels_  column_labels_  columns_  rows_
    else:
        from sklearn.cluster import KMeans as Alg
    return Alg

==> laok-0.2.16.tar.gz: laok-0.2.16/laok/ml/cluster/_sklearn.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022/5/11 21:54:21

@author: LiuKuan
@copyright: Apache License, Version 2.0
'''
#===============================================================================
'''  包装了 sklearn所支持的聚类算法
'''
#===============================================================================

cluster_list = [
    'AffinityPropagation',
    'Agglomerative',
    'Birch',
    'DBScan',
    'DBScan_daal'
    'GaussianMixture',
    'BayesianGaussianMixture',
    'KMeans',
    'KMeans_daal',
    'KMeansBisecting',
    'KMeansMiniBatch',
    'MeanShift',
    'OPTICS',
    'Spectral',
    'SpectralBiing',
    'SpectralCoing'
]

def get_cluster(_name = "KMeans", **kws):
    name = _name.lower()
    if name == 'AffinityPropagation'.lower():
        from sklearn.cluster import AffinityPropagation as Alg
    elif name == 'Agglomerative'.lower():
        from sklearn.cluster import AgglomerativeClustering as Alg
    elif name == 'Birch'.lower():
        from sklearn.cluster import Birch as Alg
    elif name == 'DBScan'.lower():
        from sklearn.cluster import DBSCAN as Alg
    elif name == 'DBScan_daal'.lower(): 
        from daal4py.sklearn.cluster import DBSCAN as Alg
    elif name == 'GaussianMixture'.lower(): 
        from sklearn.mixture import GaussianMixture as Alg
    elif name == 'BayesianGaussianMixture'.lower(): 
        from sklearn.mixture import BayesianGaussianMixture as Alg
    elif name == 'KMeans'.lower(): 
        from sklearn.cluster import KMeans as Alg
    elif name == 'KMeans_daal'.lower(): 
        from daal4py.sklearn.cluster import KMeans as Alg
    elif name == 'KMeansBisecting'.lower(): 
        from sklearn.cluster import BisectingKMeans as Alg
    elif name == 'KMeansMiniBatch'.lower(): 
        from sklearn.cluster import MiniBatchKMeans as Alg
    elif name == 'MeanShift'.lower(): 
        from sklearn.cluster import MeanShift as Alg
    elif name == 'OPTICS'.lower(): 
        from sklearn.cluster import OPTICS as Alg
    elif name == 'Spectral'.lower(): 
        from sklearn.cluster import SpectralClustering as Alg
    elif name == 'SpectralBiing'.lower(): 
        from sklearn.cluster import SpectralBiclustering as Alg
    elif name == 'SpectralCoing'.lower(): 
        from sklearn.cluster import SpectralCoclustering as Alg
    else:
        raise RuntimeError("Cann't create {}".format(_name))

    return Alg(**kws)
